==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/iot/kotlin/inputs/TopicRuleErrorActionHttpHttpHeaderArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.iot.kotlin.inputs

import com.pulumi.aws.iot.inputs.TopicRuleErrorActionHttpHttpHeaderArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property key The name of the HTTP header.
 * @property value The value of the HTTP header.
 */
public data class TopicRuleErrorActionHttpHttpHeaderArgs(
    public val key: Output<String>,
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.iot.inputs.TopicRuleErrorActionHttpHttpHeaderArgs> {
    override fun toJava(): com.pulumi.aws.iot.inputs.TopicRuleErrorActionHttpHttpHeaderArgs =
        com.pulumi.aws.iot.inputs.TopicRuleErrorActionHttpHttpHeaderArgs.builder()
            .key(key.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TopicRuleErrorActionHttpHttpHeaderArgs].
 */
@PulumiTagMarker
public class TopicRuleErrorActionHttpHttpHeaderArgsBuilder internal constructor() {
    private var key: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The name of the HTTP header.
     */
    @JvmName("fislenbphukacjdm")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The value of the HTTP header.
     */
    @JvmName("bopnmllwmbatkajo")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The name of the HTTP header.
     */
    @JvmName("epynnjubbqmsybwt")
    public suspend fun key(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The value of the HTTP header.
     */
    @JvmName("ykesmnhfwwculqkh")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): TopicRuleErrorActionHttpHttpHeaderArgs =
        TopicRuleErrorActionHttpHttpHeaderArgs(
            key = key ?: throw PulumiNullFieldException("key"),
            `value` = `value` ?: throw PulumiNullFieldException("value"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/iot/kotlin/inputs/TopicRuleErrorActionHttpHttpHeaderArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.iot.kotlin.inputs

import com.pulumi.aws.iot.inputs.TopicRuleErrorActionHttpHttpHeaderArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property key The name of the HTTP header.
 * @property value The value of the HTTP header.
 */
public data class TopicRuleErrorActionHttpHttpHeaderArgs(
    public val key: Output<String>,
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.iot.inputs.TopicRuleErrorActionHttpHttpHeaderArgs> {
    override fun toJava(): com.pulumi.aws.iot.inputs.TopicRuleErrorActionHttpHttpHeaderArgs =
        com.pulumi.aws.iot.inputs.TopicRuleErrorActionHttpHttpHeaderArgs.builder()
            .key(key.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [TopicRuleErrorActionHttpHttpHeaderArgs].
 */
@PulumiTagMarker
public class TopicRuleErrorActionHttpHttpHeaderArgsBuilder internal constructor() {
    private var key: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The name of the HTTP header.
     */
    @JvmName("wfkyfamfywxxljkh")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The value of the HTTP header.
     */
    @JvmName("sbglhldkuggxtmug")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The name of the HTTP header.
     */
    @JvmName("wvatprkhvomodmsl")
    public suspend fun key(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The value of the HTTP header.
     */
    @JvmName("wfclprnytwmhsunm")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): TopicRuleErrorActionHttpHttpHeaderArgs =
        TopicRuleErrorActionHttpHttpHeaderArgs(
            key = key ?: throw PulumiNullFieldException("key"),
            `value` = `value` ?: throw PulumiNullFieldException("value"),
        )
}
